==> InfiniTec.Exchange_0.96_Source.zip: Security/RoleMapping.cs <==
using System;

namespace InfiniTec.Exchange.Security
{
	/// <summary>
	/// This class maps <see cref="AccessRole"/> values to <see cref="ItemAccessMasks"/>
    /// and <see cref="FolderAccessMasks"/> values and vice versa.
	/// </summary>
	public class RoleMapping
	{
        private static readonly RoleMapping[] Roles = {
														new RoleMapping(AccessRole.Owner, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.CreateSubfolder | FolderAccessMasks.FolderContact | FolderAccessMasks.FolderOwner | FolderAccessMasks.FolderVisible, ItemAccessMasks.All),
                                                        new RoleMapping(AccessRole.PublishingEditor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.CreateSubfolder | FolderAccessMasks.FolderVisible, ItemAccessMasks.All),
														new RoleMapping(AccessRole.Editor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.All),
														new RoleMapping(AccessRole.PublishingAuthor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.CreateSubfolder | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem | ItemAccessMasks.DeleteOwn | ItemAccessMasks.EditOwn),
														new RoleMapping(AccessRole.Author, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem | ItemAccessMasks.DeleteOwn | ItemAccessMasks.EditOwn),
														new RoleMapping(AccessRole.NonEditingAuthor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem | ItemAccessMasks.DeleteOwn),
														new RoleMapping(AccessRole.Reviewer, FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem),
   														new RoleMapping(AccessRole.Contributor, FolderAccessMasks.CreateItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.None),
                                                        new RoleMapping(AccessRole.Contributor, FolderAccessMasks.CreateItems, ItemAccessMasks.None),
  													    new RoleMapping(AccessRole.FolderVisible, FolderAccessMasks.FolderVisible, ItemAccessMasks.None),
                                                        new RoleMapping(AccessRole.None, FolderAccessMasks.None, ItemAccessMasks.None),
													};

        private AccessRole _Role;
        private FolderAccessMasks _FolderAccessMask;
        private ItemAccessMasks _ItemAccessMask;

        /// <summary>
        /// Returns the <see cref="ItemAccessMasks"/>for the associated role
        /// </summary>
        public ItemAccessMasks ItemAccessMask
        {
            get { return _ItemAccessMask; }
        }

        /// <summary>
        /// Returns the <see cref="FolderAccessMasks"/> for the associated role
        /// </summary>
        public FolderAccessMasks FolderAccessMask
        {
            get { return _FolderAccessMask; }
        }

        /// <summary>
        /// Returns the role this instance
        /// </summary>
        public AccessRole Role
        {
            get { return _Role; }
        }

        private RoleMapping(AccessRole role, FolderAccessMasks folderAccessMask, ItemAccessMasks itemAccessMask)
        {
            _FolderAccessMask = folderAccessMask;
            _ItemAccessMask = itemAccessMask;
            _Role = role;
        }

        /// <summary>
        /// Returns the access masks for the specified role
        /// </summary>
        /// <param name="role">A valid <see cref="AccessRole"/> value</param>
        /// <returns>The item and folder mapping for the role</returns>
		public static RoleMapping GetRoleMapping(AccessRole role) 
		{
            return Array.Find<RoleMapping>(Roles, delegate(RoleMapping mapping)
            {
                return (mapping.Role == role);
            });
		}

        /// <summary>
        /// Returns the most appropiate <see cref="AccessRole"/> for the specified
        /// folder and item level access masks.
        /// </summary>
        /// <param name="folderAccessMask">A combination of the <see cref="FolderAccessMasks"/> enumeration</param>
        /// <param name="itemAccessMask">A combination of the <see cref="ItemAccessMasks"/> enumeration</param>
        /// <returns></returns>
        public static AccessRole GetAccessRole(FolderAccessMasks folderAccessMask, ItemAccessMasks itemAccessMask) 
		{
			RoleMapping roleMapping;

            roleMapping = Array.Find<RoleMapping>(Roles, delegate(RoleMapping mapping) {
                return ((mapping.FolderAccessMask & folderAccessMask) == mapping.FolderAccessMask &&
                    (mapping.ItemAccessMask & itemAccessMask) == mapping.ItemAccessMask);
            });

            return (roleMapping != null) ? roleMapping.Role : AccessRole.Special;
		}
	}
}

==> InfiniTec.Exchange_0.97_Source.zip: Security/RoleMapping.cs <==
using System;

namespace InfiniTec.Exchange.Security
{
	/// <summary>
	/// This class maps <see cref="AccessRole"/> values to <see cref="ItemAccessMasks"/>
    /// and <see cref="FolderAccessMasks"/> values and vice versa.
	/// </summary>
	public class RoleMapping
	{
        private static readonly RoleMapping[] Roles = {
														new RoleMapping(AccessRole.Owner, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.CreateSubfolder | FolderAccessMasks.FolderContact | FolderAccessMasks.FolderOwner | FolderAccessMasks.FolderVisible, ItemAccessMasks.All),
                                                        new RoleMapping(AccessRole.PublishingEditor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.CreateSubfolder | FolderAccessMasks.FolderVisible, ItemAccessMasks.All),
														new RoleMapping(AccessRole.Editor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.All),
														new RoleMapping(AccessRole.PublishingAuthor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.CreateSubfolder | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem | ItemAccessMasks.DeleteOwn | ItemAccessMasks.EditOwn),
														new RoleMapping(AccessRole.Author, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem | ItemAccessMasks.DeleteOwn | ItemAccessMasks.EditOwn),
														new RoleMapping(AccessRole.NonEditingAuthor, FolderAccessMasks.CreateItems | FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem | ItemAccessMasks.DeleteOwn),
														new RoleMapping(AccessRole.Reviewer, FolderAccessMasks.ReadItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.ReadItem),
   														new RoleMapping(AccessRole.Contributor, FolderAccessMasks.CreateItems | FolderAccessMasks.FolderVisible, ItemAccessMasks.None),
                                                        new RoleMapping(AccessRole.Contributor, FolderAccessMasks.CreateItems, ItemAccessMasks.None),
  													    new RoleMapping(AccessRole.FolderVisible, FolderAccessMasks.FolderVisible, ItemAccessMasks.None),
                                                        new RoleMapping(AccessRole.None, FolderAccessMasks.None, ItemAccessMasks.None),
													};

        private AccessRole _Role;
        private FolderAccessMasks _FolderAccessMask;
        private ItemAccessMasks _ItemAccessMask;

        /// <summary>
        /// Returns the <see cref="ItemAccessMasks"/>for the associated role
        /// </summary>
        public ItemAccessMasks ItemAccessMask
        {
            get { return _ItemAccessMask; }
        }

        /// <summary>
        /// Returns the <see cref="FolderAccessMasks"/> for the associated role
        /// </summary>
        public FolderAccessMasks FolderAccessMask
        {
            get { return _FolderAccessMask; }
        }

        /// <summary>
        /// Returns the role of this instance
        /// </summary>
        public AccessRole Role
        {
            get { return _Role; }
        }

        private RoleMapping(AccessRole role, FolderAccessMasks folderAccessMask, ItemAccessMasks itemAccessMask)
        {
            _FolderAccessMask = folderAccessMask;
            _ItemAccessMask = itemAccessMask;
            _Role = role;
        }

        /// <summary>
        /// Returns the access masks for the specified role
        /// </summary>
        /// <param name="role">A valid <see cref="AccessRole"/> value</param>
        /// <returns>The item and folder mapping for the role</returns>
		public static RoleMapping GetRoleMapping(AccessRole role) 
		{
            return Array.Find(Roles, delegate(RoleMapping mapping)
            {
                return (mapping.Role == role);
            });
		}

        /// <summary>
        /// Returns the most appropiate <see cref="AccessRole"/> for the specified
        /// folder and item level access masks.
        /// </summary>
        /// <param name="folderAccessMask">A combination of the <see cref="FolderAccessMasks"/> enumeration</param>
        /// <param name="itemAccessMask">A combination of the <see cref="ItemAccessMasks"/> enumeration</param>
        /// <returns></returns>
        public static AccessRole GetAccessRole(FolderAccessMasks folderAccessMask, ItemAccessMasks itemAccessMask) 
		{
			RoleMapping roleMapping;

            roleMapping = Array.Find(Roles, delegate(RoleMapping mapping) {
                return ((mapping.FolderAccessMask & folderAccessMask) == mapping.FolderAccessMask &&
                    (mapping.ItemAccessMask & itemAccessMask) == mapping.ItemAccessMask);
            });

            return (roleMapping != null) ? roleMapping.Role : AccessRole.Special;
		}
	}
}
